@@ -114,6 +114,15 @@ class IPXERouterView(NodeSlugMixin, RethinkAPIMixin, APIView):
         os = OperatingSystemSerializer.get(name=name)
         template = engines['django'].from_string(os['ipxe_script'])
         context = {'object': self.object, 'request': request}
+        if 'provision' in context['object']:
+            context['network'] = NetworkSerializer.get_by_asset_vlan(context['object'], context['object']['provision']['vlan'])
+            ipam = get_ipam(context['object'], False)
+            context['network']['ipam'] = ipam.ip_prefix_get(context['network'])
+            context['networks'] = []
+            for vlan in context['object']['provision'].get('vlans', []):
+                network = NetworkSerializer.get_by_asset_vlan(context['object'], vlan)
+                network['ipam'] = ipam.ip_prefix_get(network)
+                context['networks'].append({'vlan': vlan, 'network': network})
         return HttpResponse(template.render(context), content_type="text/plain")
 
 class IntakeReportView(NodeSlugMixin, RethinkAPIMixin, APIView):
@@ -328,7 +337,7 @@ class AssetIPMIActionView(RethinkAPIMixin, APIView):
             task = asset_get_by_id.s(id)
         task = task | ipmi_power_state.s()
         try:
-            result = task.apply_async().get(propagate=True)
+            result = task.apply_async(expires=settings.SOCRATES_CHANGEFEED_MAX_WAIT).get(propagate=True)
             if result is None:
                 raise Exception("Unable to determine power-state")
             return Response({'power_state': result})
